package com.faraphel.tasks_valider

import android.os.Build
import android.os.Bundle
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.annotation.RequiresApi
import androidx.compose.foundation.layout.Column
import androidx.room.Room
import androidx.room.RoomDatabase
import androidx.sqlite.db.SupportSQLiteDatabase
import com.faraphel.tasks_valider.database.Database
import com.faraphel.tasks_valider.database.entities.Group
import com.faraphel.tasks_valider.database.entities.GroupStudent
import com.faraphel.tasks_valider.database.entities.Student
import com.faraphel.tasks_valider.database.entities.Task
import com.faraphel.tasks_valider.database.entities.TaskGroup
import com.faraphel.tasks_valider.database.entities.Teacher
import com.faraphel.tasks_valider.ui.widgets.WidgetTaskStudent
import java.time.Instant


class MainActivity : ComponentActivity() {

    companion object {
        lateinit var database: Database
    }

    @RequiresApi(Build.VERSION_CODES.O)
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        // Reset the database
        this.deleteDatabase("local")  // TODO: remove

        // Create the database
        database = Room.databaseBuilder(
            this.applicationContext,
            Database::class.java, "local"
        )
        .allowMainThreadQueries()  // TODO: remove
        .build()


        // Create some data
        val studentDao = database.studentDao()
        studentDao.insert(
            Student(firstName = "John", lastName = "Joe"),
            Student(firstName = "Evan", lastName = "Doe"),
            Student(firstName = "Xavier", lastName = "Moe"),
        )

        val teacherDao = database.teacherDao()
        teacherDao.insert(
            Teacher(firstName = "Jean", lastName = "Voe")
        )

        val groupDao = database.groupDao()
        groupDao.insert(
            Group(name = "Group 1"),
            Group(name = "Group 2"),
        )

        val groupStudentDao = database.groupStudentDao()
        groupStudentDao.insert(
            GroupStudent(1, 1),
            GroupStudent(1, 2),
            GroupStudent(2, 3),
        )

        val taskDao = database.taskDao()
        taskDao.insert(
            Task(title = "Task 1", description = "Do something"),
            Task(title = "Task 2", description = "Do something else"),
            Task(title = "Task 3", description = "Do something nice"),
        )

        val taskGroupDao = database.taskGroupDao()
        taskGroupDao.insert(
            TaskGroup(1, 1),
            TaskGroup(2, 2, true, 1, Instant.now()),
        )

        /*

        // display some data
        this.setContent {
            Column {
                database.taskGroupDao().getAll().forEach { taskGroup ->
                    WidgetTaskStudent(database, taskGroup)
                }
            }
        }

         */

    }
}
